wallaroo.wallaroo_ml_ops_api_client.models.assays_list_json_body API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.assays_list_json_body

View Source

     1from typing import Any, Dict, List, Type, TypeVar, Union
     2
     3import attr
     4
     5from ..types import UNSET, Unset
     6
     7T = TypeVar("T", bound="AssaysListJsonBody")
     8
     9@attr.s(auto_attribs=True)
    10class AssaysListJsonBody:
    11    """ Request for list of assays.
    12
    13    Attributes:
    14        pipeline_id (Union[Unset, None, int]):  Optional pipeline identifier.
    15    """
    16
    17    pipeline_id: Union[Unset, None, int] = UNSET
    18    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    19
    20
    21    def to_dict(self) -> Dict[str, Any]:
    22        pipeline_id = self.pipeline_id
    23
    24        field_dict: Dict[str, Any] = {}
    25        field_dict.update(self.additional_properties)
    26        field_dict.update({
    27        })
    28        if pipeline_id is not UNSET:
    29            field_dict["pipeline_id"] = pipeline_id
    30
    31        return field_dict
    32
    33
    34
    35    @classmethod
    36    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    37        d = src_dict.copy()
    38        pipeline_id = d.pop("pipeline_id", UNSET)
    39
    40        assays_list_json_body = cls(
    41            pipeline_id=pipeline_id,
    42        )
    43
    44        assays_list_json_body.additional_properties = d
    45        return assays_list_json_body
    46
    47    @property
    48    def additional_keys(self) -> List[str]:
    49        return list(self.additional_properties.keys())
    50
    51    def __getitem__(self, key: str) -> Any:
    52        return self.additional_properties[key]
    53
    54    def __setitem__(self, key: str, value: Any) -> None:
    55        self.additional_properties[key] = value
    56
    57    def __delitem__(self, key: str) -> None:
    58        del self.additional_properties[key]
    59
    60    def __contains__(self, key: str) -> bool:
    61        return key in self.additional_properties

@attr.s(auto_attribs=True)
class AssaysListJsonBody: View Source

    10@attr.s(auto_attribs=True)
    11class AssaysListJsonBody:
    12    """ Request for list of assays.
    13
    14    Attributes:
    15        pipeline_id (Union[Unset, None, int]):  Optional pipeline identifier.
    16    """
    17
    18    pipeline_id: Union[Unset, None, int] = UNSET
    19    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    20
    21
    22    def to_dict(self) -> Dict[str, Any]:
    23        pipeline_id = self.pipeline_id
    24
    25        field_dict: Dict[str, Any] = {}
    26        field_dict.update(self.additional_properties)
    27        field_dict.update({
    28        })
    29        if pipeline_id is not UNSET:
    30            field_dict["pipeline_id"] = pipeline_id
    31
    32        return field_dict
    33
    34
    35
    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        pipeline_id = d.pop("pipeline_id", UNSET)
    40
    41        assays_list_json_body = cls(
    42            pipeline_id=pipeline_id,
    43        )
    44
    45        assays_list_json_body.additional_properties = d
    46        return assays_list_json_body
    47
    48    @property
    49    def additional_keys(self) -> List[str]:
    50        return list(self.additional_properties.keys())
    51
    52    def __getitem__(self, key: str) -> Any:
    53        return self.additional_properties[key]
    54
    55    def __setitem__(self, key: str, value: Any) -> None:
    56        self.additional_properties[key] = value
    57
    58    def __delitem__(self, key: str) -> None:
    59        del self.additional_properties[key]
    60
    61    def __contains__(self, key: str) -> bool:
    62        return key in self.additional_properties

Request for list of assays.

Attributes: pipeline_id (Union[Unset, None, int]): Optional pipeline identifier.

AssaysListJsonBody( pipeline_id: Union[wallaroo.wallaroo_ml_ops_api_client.types.Unset, NoneType, int] = <wallaroo.wallaroo_ml_ops_api_client.types.Unset object>) View Source

    2def __init__(self, pipeline_id=attr_dict['pipeline_id'].default):
    3    self.pipeline_id = pipeline_id
    4    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class AssaysListJsonBody.

def to_dict(self) -> Dict[str, Any]: View Source

    22    def to_dict(self) -> Dict[str, Any]:
    23        pipeline_id = self.pipeline_id
    24
    25        field_dict: Dict[str, Any] = {}
    26        field_dict.update(self.additional_properties)
    27        field_dict.update({
    28        })
    29        if pipeline_id is not UNSET:
    30            field_dict["pipeline_id"] = pipeline_id
    31
    32        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    36    @classmethod
    37    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    38        d = src_dict.copy()
    39        pipeline_id = d.pop("pipeline_id", UNSET)
    40
    41        assays_list_json_body = cls(
    42            pipeline_id=pipeline_id,
    43        )
    44
    45        assays_list_json_body.additional_properties = d
    46        return assays_list_json_body

additional_keys: List[str]